@@ -24,7 +24,8 @@ Runs Data::Dumper's Dumper with $Data::Dumper::Terse set to 1.
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
