@@ -19,7 +19,8 @@ PXML::Serialize::t -- tests for PXML::Serialize
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
